==> llm-docs-0.1.5.tgz: package/docs/api/openapi-validation.md <==
---
id: api-openapi-validation
---
# OpenAPI Validation Guide

<!-- title: OpenAPI Validation Guide -->
<!-- description: Guide for OpenAPI validation and API documentation in the LLM Platform Platform -->
<!-- lastUpdated: 2024-03-19 -->

## Overview

This guide details the OpenAPI validation and API documentation practices for the LLM Platform Platform. All API endpoints, methods, parameters, responses, and schemas must be explicitly defined, documented, and validated using the latest OpenAPI standards.

## Architecture

### Core Components

1. **OpenAPI Specification**
   - API endpoints
   - Request/response schemas
   - Authentication
   - Error handling
   - Versioning

2. **Validation Tools**
   - Spectral linter
   - Redocly validator
   - Swagger UI
   - Custom validators

3. **Documentation Tools**
   - Widdershins
   - Redoc
   - Swagger UI
   - Custom generators

## Implementation Guide

### OpenAPI Specification

```yaml
# openapi/main.yaml
openapi: 3.1.0
info:
  title: LLM Platform Platform API
  version: 1.0.0
  description: API for the LLM Platform AI Platform

servers:
  - url: https://api.bluefly.io/v1
    description: Production server

components:
  securitySchemes:
    bearerAuth:
      type: http
      scheme: bearer
      bearerFormat: JWT

  schemas:
    Error:
      type: object
      properties:
        code:
          type: string
        message:
          type: string
        details:
          type: object

paths:
  /agents:
    get:
      summary: List agents
      security:
        - bearerAuth: []
      responses:
        '200':
          description: List of agents
          content:
            application/json:
              schema:
                type: array
                items:
                  $ref: '#/components/schemas/Agent'
```

### Validation Setup

1. **Spectral Rules**
   ```yaml
   # .spectral.yaml
   extends: spectral:oas
   rules:
     operation-tags:
       description: Operations must have tags
       severity: error
     operation-description:
       description: Operations must have descriptions
       severity: error
     schema-description:
       description: Schemas must have descriptions
       severity: error
   ```

2. **Redocly Configuration**
   ```yaml
   # redocly.yaml
   apiDefinitions:
     main: openapi/main.yaml
   lint:
     extends:
       - recommended
     rules:
       operation-tags: error
       operation-description: error
       schema-description: error
   ```

### Documentation Generation

1. **Widdershins Setup**
   ```bash
   # Generate markdown
   npx widdershins openapi/main.yaml -o docs/api.md
   
   # Generate HTML
   npx redoc-cli bundle openapi/main.yaml -o docs/api.html
   ```

2. **Custom Generator**
   ```typescript
   // src/generators/api-docs.ts
   export class APIDocGenerator {
     async generateDocs(spec: OpenAPISpec): Promise<void> {
       // Generate documentation
     }
     
     async validateSpec(spec: OpenAPISpec): Promise<ValidationResult> {
       // Validate specification
     }
   }
   ```

## Integration Guide

### CI/CD Integration

1. **GitLab CI**
   ```yaml
   # .gitlab-ci.yml
   validate-api:
     stage: test
     script:
       - npm install -g @redocly/cli
       - redocly lint openapi/main.yaml
       - redocly bundle openapi/main.yaml -o docs/api.html
   ```

2. **GitHub Actions**
   ```yaml
   # .github/workflows/api.yml
   name: API Validation
   on: [push, pull_request]
   jobs:
     validate:
       runs-on: ubuntu-latest
       steps:
         - uses: actions/checkout@v2
         - uses: actions/setup-node@v2
         - run: npm install -g @redocly/cli
         - run: redocly lint openapi/main.yaml
   ```

### Development Workflow

1. **Local Development**
   ```bash
   # Install tools
   npm install -g @redocly/cli spectral-cli
   
   # Validate spec
   spectral lint openapi/main.yaml
   
   # Preview docs
   redocly preview-docs openapi/main.yaml
   ```

2. **Documentation Updates**
   ```bash
   # Generate markdown
   npx widdershins openapi/main.yaml -o docs/api.md
   
   # Generate HTML
   npx redoc-cli bundle openapi/main.yaml -o docs/api.html
   ```

## Best Practices

1. **Specification**
   - Use OpenAPI 3.1.0
   - Include all endpoints
   - Document all parameters
   - Define error responses
   - Use proper schemas

2. **Validation**
   - Run validation in CI
   - Use strict rules
   - Check examples
   - Validate security
   - Test endpoints

3. **Documentation**
   - Keep docs updated
   - Include examples
   - Document errors
   - Add descriptions
   - Use proper formatting

4. **Security**
   - Define security schemes
   - Document auth flows
   - Include scopes
   - Validate tokens
   - Test security

## Related Documentation

- [API Reference](reference)
- [API Normalization](normalization)
- [REST API](rest)
- [GraphQL API](graphql)
- [Security Guide](../operations/security)
- [Development Guide](../development/README)

==> llm-docs-1.0.1.tgz: package/docs/api/openapi-validation.md <==
---
id: api-openapi-validation
---
# OpenAPI Validation Guide

<!-- title: OpenAPI Validation Guide -->
<!-- description: Guide for OpenAPI validation and API documentation in the Bluefly Platform -->
<!-- lastUpdated: 2024-03-19 -->

## Overview

This guide details the OpenAPI validation and API documentation practices for the Bluefly Platform. All API endpoints, methods, parameters, responses, and schemas must be explicitly defined, documented, and validated using the latest OpenAPI standards.

## Architecture

### Core Components

1. **OpenAPI Specification**
   - API endpoints
   - Request/response schemas
   - Authentication
   - Error handling
   - Versioning

2. **Validation Tools**
   - Spectral linter
   - Redocly validator
   - Swagger UI
   - Custom validators

3. **Documentation Tools**
   - Widdershins
   - Redoc
   - Swagger UI
   - Custom generators

## Implementation Guide

### OpenAPI Specification

```yaml
# openapi/main.yaml
openapi: 3.1.0
info:
  title: Bluefly Platform API
  version: 1.0.0
  description: API for the Bluefly AI Platform

servers:
  - url: https://api.bluefly.io/v1
    description: Production server

components:
  securitySchemes:
    bearerAuth:
      type: http
      scheme: bearer
      bearerFormat: JWT

  schemas:
    Error:
      type: object
      properties:
        code:
          type: string
        message:
          type: string
        details:
          type: object

paths:
  /agents:
    get:
      summary: List agents
      security:
        - bearerAuth: []
      responses:
        '200':
          description: List of agents
          content:
            application/json:
              schema:
                type: array
                items:
                  $ref: '#/components/schemas/Agent'
```

### Validation Setup

1. **Spectral Rules**
   ```yaml
   # .spectral.yaml
   extends: spectral:oas
   rules:
     operation-tags:
       description: Operations must have tags
       severity: error
     operation-description:
       description: Operations must have descriptions
       severity: error
     schema-description:
       description: Schemas must have descriptions
       severity: error
   ```

2. **Redocly Configuration**
   ```yaml
   # redocly.yaml
   apiDefinitions:
     main: openapi/main.yaml
   lint:
     extends:
       - recommended
     rules:
       operation-tags: error
       operation-description: error
       schema-description: error
   ```

### Documentation Generation

1. **Widdershins Setup**
   ```bash
   # Generate markdown
   npx widdershins openapi/main.yaml -o docs/api.md
   
   # Generate HTML
   npx redoc-cli bundle openapi/main.yaml -o docs/api.html
   ```

2. **Custom Generator**
   ```typescript
   // src/generators/api-docs.ts
   export class APIDocGenerator {
     async generateDocs(spec: OpenAPISpec): Promise<void> {
       // Generate documentation
     }
     
     async validateSpec(spec: OpenAPISpec): Promise<ValidationResult> {
       // Validate specification
     }
   }
   ```

## Integration Guide

### CI/CD Integration

1. **GitLab CI**
   ```yaml
   # .gitlab-ci.yml
   validate-api:
     stage: test
     script:
       - npm install -g @redocly/cli
       - redocly lint openapi/main.yaml
       - redocly bundle openapi/main.yaml -o docs/api.html
   ```

2. **GitHub Actions**
   ```yaml
   # .github/workflows/api.yml
   name: API Validation
   on: [push, pull_request]
   jobs:
     validate:
       runs-on: ubuntu-latest
       steps:
         - uses: actions/checkout@v2
         - uses: actions/setup-node@v2
         - run: npm install -g @redocly/cli
         - run: redocly lint openapi/main.yaml
   ```

### Development Workflow

1. **Local Development**
   ```bash
   # Install tools
   npm install -g @redocly/cli spectral-cli
   
   # Validate spec
   spectral lint openapi/main.yaml
   
   # Preview docs
   redocly preview-docs openapi/main.yaml
   ```

2. **Documentation Updates**
   ```bash
   # Generate markdown
   npx widdershins openapi/main.yaml -o docs/api.md
   
   # Generate HTML
   npx redoc-cli bundle openapi/main.yaml -o docs/api.html
   ```

## Best Practices

1. **Specification**
   - Use OpenAPI 3.1.0
   - Include all endpoints
   - Document all parameters
   - Define error responses
   - Use proper schemas

2. **Validation**
   - Run validation in CI
   - Use strict rules
   - Check examples
   - Validate security
   - Test endpoints

3. **Documentation**
   - Keep docs updated
   - Include examples
   - Document errors
   - Add descriptions
   - Use proper formatting

4. **Security**
   - Define security schemes
   - Document auth flows
   - Include scopes
   - Validate tokens
   - Test security

## Related Documentation

- [API Reference](reference)
- [API Normalization](normalization)
- [REST API](rest)
- [GraphQL API](graphql)
- [Security Guide](../operations/security)
- [Development Guide](../development/README)
